@@ -4,10 +4,10 @@
  * protocol plus additional methods which are useful for managing the
  * contents of the document.
  *
- * Copyright (C) 1999,2002,2003,2004,2005 Free Software Foundation, Inc.
+ * Copyright (C) 1999,2002,2003,2004,2005,2020,2021 Free Software Foundation, Inc.
  *
  * Author:      Gregory John Casamento <greg_casamento@yahoo.com>
- * Date:        2002,2003,2004,2005
+ * Date:        2002,2003,2004,2005,2020,2021
  * Author:	Richard Frith-Macdonald <richard@brainstrom.co.uk>
  * Date:	1999
  *
@@ -499,9 +499,12 @@ static NSImage  *fileImage = nil;
   if ([connections indexOfObjectIdenticalTo: aConnector] == NSNotFound)
     {
       NSNotificationCenter	*nc = [NSNotificationCenter defaultCenter];
+
       [nc postNotificationName: IBWillAddConnectorNotification
 			object: aConnector];
+
       [connections addObject: aConnector];
+
       [nc postNotificationName: IBDidAddConnectorNotification
 			object: aConnector];
     }
@@ -521,6 +524,7 @@ static NSImage  *fileImage = nil;
 - (void) _instantiateFontManager
 {
   GSNibItem *item = nil;
+  NSMenu *fontMenu = nil;
   
   item = [[GormObjectProxy alloc] initWithClassName: @"NSFontManager"];
   
@@ -531,23 +535,28 @@ static NSImage  *fileImage = nil;
   // set the holder in the document.
   fontManager = (GormObjectProxy *)item;
   [self changeToViewWithTag: 0];
+
+  // Add the connection to the menu from the font manager, if the NSFontMenu exists...
+  fontMenu = [self fontMenu];
+  if (fontMenu != nil)
+    {
+      NSNibOutletConnector *con = [[NSNibOutletConnector alloc] init];
+      [con setSource: item];
+      [con setDestination: fontMenu];
+      [con setLabel: @"menu"];
+      [self addConnector: con];
+    }
 }
 
 /**
- * Attach anObject to the document with aParent.
+ * Attach anObject to the document with aParent specifying the name.  To allow
+ * Gorm to generate the name pass in nil for aName parameter
  */
-- (void) attachObject: (id)anObject toParent: (id)aParent
+- (void) attachObject: (id)anObject toParent: (id)aParent withName: (NSString *)aName
 {
   NSArray *old;
   BOOL newObject = NO;
-  /*
-  if ([self containsObject: anObject] &&
-      [anObject isKindOfClass: [NSWindow class]] == NO &&
-      [anObject isKindOfClass: [NSPanel class]] == NO)
-    {
-      return;
-    }
-  */
+
   // Modify the document whenever something is added...
   [self touch];
 
@@ -581,7 +590,7 @@ static NSImage  *fileImage = nil;
   if ([self nameForObject: anObject] == nil)
     {
       newObject = YES;
-      [self setName: nil forObject: anObject];
+      [self setName: aName forObject: anObject];
     }
 
   /*
@@ -601,7 +610,7 @@ static NSImage  *fileImage = nil;
 	  // Turn off the release when closed flag, add the content view.
 	  [anObject setReleasedWhenClosed: NO];
 	  [self attachObject: contentView
-		toParent: anObject];
+		    toParent: anObject];
 
 	  // Add all subviews from the window, if any.
           [self attachObjects: subviews toParent: win];
@@ -635,6 +644,7 @@ static NSImage  *fileImage = nil;
       // the proxy instead.
       [self _instantiateFontManager];
     }
+
   /*
    * Add the menu items from the popup.
    */
@@ -668,7 +678,7 @@ static NSImage  *fileImage = nil;
       // will become the main menu.
       if([self objectForName: @"NSMenu"] == nil)
 	{
-	  [self setName: @"NSMenu" forObject: menu];
+          [self setName: @"NSMenu" forObject: menu];
 	  [objectsView addObject: menu];
 	  [topLevelObjects addObject: menu];
 	  isMainMenu = YES;
@@ -687,6 +697,10 @@ static NSImage  *fileImage = nil;
 	    {
 	      [self setRecentDocumentsMenu: menu];
 	    }
+	  if([[menu title] isEqual: @"Font"] && [self fontMenu] == nil)
+	    {
+	      [self setFontMenu: menu];
+	    }
 	  // if it doesn't have a supermenu and it's owned by the file's owner, then it's a top level menu....
 	  else if([menu supermenu] == nil && aParent == filesOwner)
 	    {
@@ -777,17 +791,27 @@ static NSImage  *fileImage = nil;
       // Add all subviews from the window, if any.
       [self attachObjects: [view subviews] toParent: view];
     }
-
-  // Attach the cell of an item to the document so that it has a name and
-  // can be addressed.
-  if ([anObject respondsToSelector: @selector(cell)])
+  /*
+   * Add columns to document hierarchy...
+   */
+  else if ([anObject isKindOfClass: [NSTableView class]]) // this should include outline view
     {
-      [self attachObject: [anObject cell] toParent: anObject];
-    }
+      NSTableView *tblView = (NSTableView *)anObject;
+      NSArray *cols = [tblView tableColumns];
 
-  // Detect and add any connection the object might have.
-  // This is done so that any palette items which have predefined connections will be
-  // shown in the connections list.
+      [self attachObjects: cols toParent: tblView];
+    }
+  else if ([anObject isKindOfClass: [NSSplitView class]])
+    {
+      NSSplitView *sp = (NSSplitView *)anObject;
+      [self attachObjects: [sp subviews] toParent: sp];
+    }
+  
+  /* 
+   * Detect and add any connection the object might have.
+   * This is done so that any palette items which have predefined connections will be
+   * shown in the connections list.
+   */
   if([anObject respondsToSelector: @selector(action)]  &&
      [anObject respondsToSelector: @selector(target)]  &&
      newObject)
@@ -853,6 +877,39 @@ static NSImage  *fileImage = nil;
 	  RELEASE(con);
 	}
     }
+
+  /*
+   * Attach the cell of an item to the document so that it has a name and
+   * can be addressed.  Do this last so that all other considerations are taken care
+   * of prior to adding the cell to the document.
+   */
+  if ([anObject respondsToSelector: @selector(cell)])
+    {
+      [self openEditorForObject: [anObject cell]
+	       withParentObject: anObject];
+      [self attachObject: [anObject cell] toParent: anObject];
+    }
+}
+
+/**
+ * Attach an object to parent object in document letting Gorm generate the name
+ */ 
+- (void) attachObject: (id)object toParent: (id)parent
+{
+  [self attachObject: object
+            toParent: parent
+            withName: nil];
+}
+
+/**
+ * Attach an object to parent object in document letting Gorm generate the name
+ * this method will add a top level object.
+ */ 
+- (void) attachObject: (id)object
+{
+  [self attachObject: object
+            toParent: nil
+            withName: nil];
 }
 
 /**
@@ -1157,7 +1214,7 @@ static NSImage  *fileImage = nil;
 - (void) dealloc
 {
   [[NSNotificationCenter defaultCenter] removeObserver: self];
-  ASSIGN(lastEditor, nil);
+  ASSIGN(lastEditor, (id)nil);
   // [filePrefsWindow close];
 
   // Get rid of the selection box.
@@ -1249,7 +1306,13 @@ static NSImage  *fileImage = nil;
       NSArray          *objs = [self retrieveObjectsForParent: anObject recursively: NO];
       id               editor = [self editorForObject: anObject create: NO];
       id               parent = [self parentEditorForEditor: editor];
+      NSNotificationCenter *nc = [NSNotificationCenter defaultCenter];
 
+      RETAIN(anObject); // prevent release of object during notifications...
+      [nc postNotificationName: GormWillDetachObjectFromDocumentNotification
+                        object: anObject
+                      userInfo: nil];
+      
       // close the editor...
       if (close_editor)
         {
@@ -1359,6 +1422,11 @@ static NSImage  *fileImage = nil;
       
       RELEASE(name); // retained at beginning of method...
       [self touch]; // set the document as modified
+
+      [nc postNotificationName: GormDidDetachObjectFromDocumentNotification
+                        object: anObject
+                      userInfo: nil];
+      RELEASE(anObject); // release since notifications are done.
     }
 }
 
@@ -1545,6 +1613,7 @@ static NSImage  *fileImage = nil;
            */
 	  anEditor = objectsView;
 	}
+      
       if (anEditor != editor)
 	{
 	  /*
@@ -1867,6 +1936,7 @@ static void _real_close(GormDocument *self,
   NSString	*name;
 
   NSDebugLog(@"------ Rebuilding object to name mapping...");
+
   NSResetMapTable(objToName);
   NSMapInsert(objToName, (void*)filesOwner, (void*)@"NSOwner");
   NSMapInsert(objToName, (void*)firstResponder, (void*)@"NSFirst");
@@ -1878,20 +1948,26 @@ static void _real_close(GormDocument *self,
       NSDebugLog(@"%@ --> %@",name, obj);
 
       NSMapInsert(objToName, (void*)obj, (void*)name);
-      if (([obj isKindOfClass: [NSMenu class]] && [name isEqual: @"NSMenu"]) || [obj isKindOfClass: [NSWindow class]])
+      if (([obj isKindOfClass: [NSMenu class]] && [name isEqual: @"NSMenu"]) ||
+	  [obj isKindOfClass: [NSWindow class]])
 	{
 	  [[self openEditorForObject: obj] activate];
 	}
     }
+
+  NSDebugLog(@"------ Done rebuilding object to name mapping...");
 }
 
 /**
- * Open the editor for anObject.
+ * Open the editor for anObject, with parent object.
  */
 - (id<IBEditors>) openEditorForObject: (id)anObject
+		     withParentObject: (id)parentObj
 {
-  id<IBEditors>	e = [self editorForObject: anObject create: YES];
-  id<IBEditors, IBSelectionOwners> p = [self parentEditorForEditor: e];
+  BOOL f = ([anObject isKindOfClass: [NSCell class]] == NO);
+  id<IBEditors> pe = [self editorForObject: parentObj create: NO];
+  id<IBEditors>	e = [self editorForObject: anObject inEditor: pe create: f];
+  id<IBEditors> p = (parentObj == nil) ? [self parentEditorForEditor: e] : pe;
   
   if (p != nil && p != objectsView)
     {
@@ -1908,6 +1984,14 @@ static void _real_close(GormDocument *self,
   return e;
 }
 
+/**
+ * Open the editor for anObject.
+ */
+- (id<IBEditors>) openEditorForObject: (id)anObject
+{
+  return [self openEditorForObject: anObject withParentObject: nil];
+}
+
 /**
  * Return the parent editor for anEditor.
  */
@@ -2021,19 +2105,22 @@ static void _real_close(GormDocument *self,
 - (void) removeConnector: (id<IBConnectors>)aConnector
 {
   NSNotificationCenter	*nc = [NSNotificationCenter defaultCenter];
-
+  
   RETAIN(aConnector); // prevent it from being dealloc'd until the notification is done.
-  // issue pre notification..
- [nc postNotificationName: IBWillRemoveConnectorNotification
-      object: aConnector];
 
+  // issue pre notification..
+  [nc postNotificationName: IBWillRemoveConnectorNotification
+                    object: aConnector];
+  
   // mark the document as changed.
   [self touch];
-
-  // issue post notification..
+  
   [connections removeObjectIdenticalTo: aConnector];
+  
+  // issue post notification..
   [nc postNotificationName: IBDidRemoveConnectorNotification
-      object: aConnector];
+                    object: aConnector];
+  
   RELEASE(aConnector); // NOW we can dealloc it.
 }
 
@@ -2282,6 +2369,29 @@ static void _real_close(GormDocument *self,
   return [nameTable objectForKey: @"NSServicesMenu"];
 }
 
+/**
+ * Set the object that will be the font menu in the app.
+ */
+- (void) setFontMenu: (NSMenu *)anObject
+{
+  if(anObject != nil)
+    {
+      [nameTable setObject: anObject forKey: @"NSFontMenu"];
+    }
+  else
+    {
+      [nameTable removeObjectForKey: @"NSFontMenu"];
+    }
+}
+
+/**
+ * Return the object that will be the services menu.
+ */
+- (NSMenu *) fontMenu
+{
+  return [nameTable objectForKey: @"NSFontMenu"];
+}
+
 /**
  * Set the menu that will be the recent documents menu in the app.
  */
@@ -3515,6 +3625,11 @@ static void _real_close(GormDocument *self,
   return isOlderArchive;
 }
 
+//
+// Encoding is here for testing the interface.  This allows
+// Gorm to encode the interface and then run it like a regular
+// app.  It needs to act like a container in order to do this.
+//
 - (void) encodeWithCoder: (NSCoder *)coder
 {
   [coder encodeObject: topLevelObjects];
@@ -3529,16 +3644,34 @@ static void _real_close(GormDocument *self,
   ASSIGN(nameTable, [coder decodeObject]);
   ASSIGN(visibleWindows, [coder decodeObject]);
   ASSIGN(connections, [coder decodeObject]);
-
+  
   return self;
 }
-
+  
 - (void) awakeWithContext: (NSDictionary *)context
 {
   NSEnumerator *en = [connections objectEnumerator];
   id o = nil;
+  
   while((o = [en nextObject]) != nil)
     {
+      id val = nil;
+
+      if ([o destination] == firstResponder)
+	{
+	  val = nil;
+	}
+      else
+	{
+	  val = [nameTable objectForKey: [o destination]];
+	}
+
+      if ([[o label] isEqualToString: @"terminate:"])
+	{
+	  [o setLabel: @"deferredEndTesting:"];
+	}
+      
+      [o setDestination: val];
       [o establishConnection];
     }
 
@@ -3549,6 +3682,7 @@ static void _real_close(GormDocument *self,
       [o orderFront: self];
     }
 }
+/* End of testInterface support code */
 
 /**
  * Deactivate the editors for archiving..
