@@ -1,4 +1,4 @@
-/* All Rights reserved */
+/* All rights reserved */
 
 #include <AppKit/AppKit.h>
 
@@ -25,15 +25,18 @@
     {
       if ([NSBundle loadNibNamed: @"GormNSSplitViewInspector" 
 		    owner: self] == NO)
-	{
-	  
-	  NSDictionary	*table;
-	  NSBundle	*bundle;
+	{	  
+	  NSDictionary	*table = nil;
+	  NSBundle	*bundle = nil;
+          BOOL           loaded = NO;
+          
 	  table = [NSDictionary dictionaryWithObject: self forKey: @"NSOwner"];
 	  bundle = [NSBundle mainBundle];
-	  if ([bundle loadNibFile: @"GormNSSplitViewInspector"
-		      externalNameTable: table
-		      withZone: [self zone]] == NO)
+          loaded = [bundle loadNibFile: @"GormNSSplitViewInspector"
+                     externalNameTable: table
+                              withZone: [self zone]];
+
+          if (!loaded)
 	    {
 	      NSLog(@"Could not open gorm GormNSSplitViewInspector");
 	      NSLog(@"self %@", self);
@@ -47,15 +50,13 @@
 
 - (void)awakeFromNib
 {
-  for (NSCell *cell in [orientation cells])
-    {
-      [cell setRefusesFirstResponder: YES];
-    }
 }
 
 - (void) _getValuesFromObject
 {
   BOOL state = [(NSSplitView *)object isVertical];
+  NSUInteger dividerStyle = [(NSSplitView *)object dividerStyle];
+  
   // get the values from the object
   if(state == NO)
     {
@@ -65,6 +66,8 @@
     {
       [orientation selectCellAtRow: 1 column: 0];      
     }
+
+  [divider selectItemWithTag: dividerStyle];
 }
 
 - (void) setObject: (id)anObject
@@ -77,13 +80,17 @@
 {
   id cell = nil;
   BOOL state = NO;
-
+  NSUInteger styleTag = 0;
+  
   // horizontal switch..  if it's active/inactive we 
   // know what the selection is.
   [super ok: sender];
   cell = [orientation cellAtRow: 0 column: 0];
   state = ([cell state] == NSOnState)?NO:YES;
+  styleTag = [divider selectedTag];
+  
   [object setVertical: state];
   [object adjustSubviews];
+  [object setDividerStyle: styleTag];
 }
 @end
