@@ -24,7 +24,7 @@
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 */
 
-/* All Rights reserved */
+/* All rights reserved */
 
 #include <AppKit/AppKit.h>
 
@@ -101,7 +101,7 @@
 - (void) pause: (id)sender
 {
   NSDebugLog(@"Pause");
-  [object pause];
+  [(NSSound *)object pause];
 }
 
 - (void) record: (id)sender
