@@ -247,16 +247,16 @@ int defaultDateFormatIndex = 3;
   tv = [[NSTextView alloc] initWithFrame: rect];
   [tv setMinSize: NSMakeSize(108.0, 143.0)];
   [tv setMaxSize: NSMakeSize(1.0E7,1.0E7)];
-  [tv setHorizontallyResizable: YES];
   [tv setVerticallyResizable: YES];
+  [tv setHorizontallyResizable: NO];
   [tv setAutoresizingMask: NSViewHeightSizable | NSViewWidthSizable];
   [tv setSelectable: YES];
   [tv setEditable: YES];
   [tv setRichText: YES];
   [tv setImportsGraphics: YES];
 
-  [[tv textContainer] setContainerSize:NSMakeSize(rect.size.width,1e7)];
-  [[tv textContainer] setWidthTracksTextView:YES];
+  // [[tv textContainer] setContainerSize:NSMakeSize(rect.size.width,1e7)];
+  // [[tv textContainer] setWidthTracksTextView:YES];
   
   [v setDocumentView:tv];
   [contents addSubview: v];
