@@ -27,10 +27,11 @@
 #ifndef INCLUDED_GormTextViewEditor_h
 #define INCLUDED_GormTextViewEditor_h
 
-#include <InterfaceBuilder/InterfaceBuilder.h>
 #include <Foundation/Foundation.h>
 #include <AppKit/AppKit.h>
-#include <GormCore/GormViewEditor.h>
+
+#include <InterfaceBuilder/InterfaceBuilder.h>
+#include <GormCore/GormCore.h>
 
 @interface GormTextViewEditor : GormViewEditor
 {
